# XpathWebScrapper
Simple and easy configurable web scrapper using lxml

## Usage:
```
$ pip install xpathwebscrapper
$ xpathwebscrapper -h
usage: xpathwebscrapper [-h] yml xlsx

positional arguments:
  yml         site_definition.yml
  xlsx        result.xlsx

optional arguments:
  -h, --help  show this help message and exit
```

**For .yml reference look Examples/**
